# Blender Stuff

## Addons

Scatter things, bool tools, many goodies
: bagapie => https://www.f12studio.fr/bagapie

Library of models, textures & HDRI
: https://www.blenderkit.com/

## Companions / 3rd party apps

Extract textures from image
: https://sandripper.vercel.app/

Still image matching
: fspy

## Misc links (may be outdated)
Get Free Textures:
- https://ambientcg.com/
- https://3dprintermarket.co.uk/
- https://texturebox.com/
- https://locationtextures.com/
-----------------------------------------
- FREE - 90 Nascar Decals: https://artstn.co/m/LpLW6
- Free Sample Ref Pack: https://artstn.co/m/D0zM
- Get Free Action VFX Files: https://www.actionvfx.com/collections...
- Get PickPack: http://www.p43d.com/pickpicpack
- Get Free Stuff on Cubebrush: https://www.cubebrush.co/?freebies=true
- 5 Free Knitted Fabric Materials  - https://bit.ly/3EE2wmY
- 50 Free HATS BASEMESH - https://bit.ly/3HpMuPb
- 20-Sleeves-Marvelous designer: https://www.artstation.com/a/11993139
- 50 Blender Rope Tools:- https://www.artstation.com/a/11993142
- FREE ZBrush Matcap: https://www.artstation.com/a/6610789